@@ -56,7 +56,7 @@ typedef Eo Efl_Io_Buffered_Stream;
  */
 #define EFL_IO_BUFFERED_STREAM_CLASS efl_io_buffered_stream_class_get()
 
-EWAPI const Efl_Class *efl_io_buffered_stream_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_io_buffered_stream_class_get(void) EINA_CONST;
 
 /**
  * @brief The inner I/O this wrapper operates on.
@@ -68,7 +68,7 @@ EWAPI const Efl_Class *efl_io_buffered_stream_class_get(void);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_inner_io_set(Eo *obj, Efl_Object *io);
+EAPI EAPI_WEAK void efl_io_buffered_stream_inner_io_set(Eo *obj, Efl_Object *io);
 
 /**
  * @brief The inner I/O this wrapper operates on.
@@ -81,7 +81,7 @@ EOAPI void efl_io_buffered_stream_inner_io_set(Eo *obj, Efl_Object *io);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI Efl_Object *efl_io_buffered_stream_inner_io_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Object *efl_io_buffered_stream_inner_io_get(const Eo *obj);
 
 /**
  * @brief Limits how big the input queue can grow, in bytes.
@@ -97,7 +97,7 @@ EOAPI Efl_Object *efl_io_buffered_stream_inner_io_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_max_queue_size_input_set(Eo *obj, size_t max_queue_size_input);
+EAPI EAPI_WEAK void efl_io_buffered_stream_max_queue_size_input_set(Eo *obj, size_t max_queue_size_input);
 
 /**
  * @brief Limits how big the input queue can grow, in bytes.
@@ -112,7 +112,7 @@ EOAPI void efl_io_buffered_stream_max_queue_size_input_set(Eo *obj, size_t max_q
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI size_t efl_io_buffered_stream_max_queue_size_input_get(const Eo *obj);
+EAPI EAPI_WEAK size_t efl_io_buffered_stream_max_queue_size_input_get(const Eo *obj);
 
 /**
  * @brief Limits how big the output queue can grow in bytes.
@@ -128,7 +128,7 @@ EOAPI size_t efl_io_buffered_stream_max_queue_size_input_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_max_queue_size_output_set(Eo *obj, size_t max_queue_size_output);
+EAPI EAPI_WEAK void efl_io_buffered_stream_max_queue_size_output_set(Eo *obj, size_t max_queue_size_output);
 
 /**
  * @brief Limits how big the output queue can grow in bytes.
@@ -143,7 +143,7 @@ EOAPI void efl_io_buffered_stream_max_queue_size_output_set(Eo *obj, size_t max_
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI size_t efl_io_buffered_stream_max_queue_size_output_get(const Eo *obj);
+EAPI EAPI_WEAK size_t efl_io_buffered_stream_max_queue_size_output_get(const Eo *obj);
 
 /**
  * @brief If set incoming data will be checked for the delimiter and "line"
@@ -157,7 +157,7 @@ EOAPI size_t efl_io_buffered_stream_max_queue_size_output_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_line_delimiter_set(Eo *obj, const Eina_Slice slice);
+EAPI EAPI_WEAK void efl_io_buffered_stream_line_delimiter_set(Eo *obj, const Eina_Slice slice);
 
 /**
  * @brief If set incoming data will be checked for the delimiter and "line"
@@ -170,7 +170,7 @@ EOAPI void efl_io_buffered_stream_line_delimiter_set(Eo *obj, const Eina_Slice s
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI Eina_Slice efl_io_buffered_stream_line_delimiter_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Slice efl_io_buffered_stream_line_delimiter_get(const Eo *obj);
 
 /**
  * @brief Error as ETIMEDOUT if it becomes inactive for some time.
@@ -187,7 +187,7 @@ EOAPI Eina_Slice efl_io_buffered_stream_line_delimiter_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_timeout_inactivity_set(Eo *obj, double seconds);
+EAPI EAPI_WEAK void efl_io_buffered_stream_timeout_inactivity_set(Eo *obj, double seconds);
 
 /**
  * @brief Error as ETIMEDOUT if it becomes inactive for some time.
@@ -205,7 +205,7 @@ EOAPI void efl_io_buffered_stream_timeout_inactivity_set(Eo *obj, double seconds
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI double efl_io_buffered_stream_timeout_inactivity_get(const Eo *obj);
+EAPI EAPI_WEAK double efl_io_buffered_stream_timeout_inactivity_get(const Eo *obj);
 
 /**
  * @brief Reads chunk size property, in bytes.
@@ -229,7 +229,7 @@ EOAPI double efl_io_buffered_stream_timeout_inactivity_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_read_chunk_size_set(Eo *obj, size_t size);
+EAPI EAPI_WEAK void efl_io_buffered_stream_read_chunk_size_set(Eo *obj, size_t size);
 
 /**
  * @brief Reads chunk size property, in bytes.
@@ -252,7 +252,7 @@ EOAPI void efl_io_buffered_stream_read_chunk_size_set(Eo *obj, size_t size);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI size_t efl_io_buffered_stream_read_chunk_size_get(const Eo *obj);
+EAPI EAPI_WEAK size_t efl_io_buffered_stream_read_chunk_size_get(const Eo *obj);
 
 /**
  * @brief How many bytes are pending write to
@@ -264,7 +264,7 @@ EOAPI size_t efl_io_buffered_stream_read_chunk_size_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI size_t efl_io_buffered_stream_pending_write_get(const Eo *obj);
+EAPI EAPI_WEAK size_t efl_io_buffered_stream_pending_write_get(const Eo *obj);
 
 /**
  * @brief How many bytes are pending (available) for read
@@ -275,7 +275,7 @@ EOAPI size_t efl_io_buffered_stream_pending_write_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI size_t efl_io_buffered_stream_pending_read_get(const Eo *obj);
+EAPI EAPI_WEAK size_t efl_io_buffered_stream_pending_read_get(const Eo *obj);
 
 /**
  * @brief How many bytes were written and read.
@@ -286,7 +286,7 @@ EOAPI size_t efl_io_buffered_stream_pending_read_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_progress_get(const Eo *obj, size_t *read_bytes, size_t *written_bytes);
+EAPI EAPI_WEAK void efl_io_buffered_stream_progress_get(const Eo *obj, size_t *read_bytes, size_t *written_bytes);
 
 /**
  * @brief Gets a temporary access to input queue's internal read memory.
@@ -303,7 +303,7 @@ EOAPI void efl_io_buffered_stream_progress_get(const Eo *obj, size_t *read_bytes
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI Eina_Slice efl_io_buffered_stream_slice_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Slice efl_io_buffered_stream_slice_get(const Eo *obj);
 
 /**
  * @brief Discards the given number of bytes.
@@ -327,7 +327,7 @@ EOAPI Eina_Slice efl_io_buffered_stream_slice_get(const Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_discard(Eo *obj, size_t amount);
+EAPI EAPI_WEAK void efl_io_buffered_stream_discard(Eo *obj, size_t amount);
 
 /**
  * @brief Clears the incoming queue. Same as reading all data.
@@ -338,7 +338,7 @@ EOAPI void efl_io_buffered_stream_discard(Eo *obj, size_t amount);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_clear(Eo *obj);
+EAPI EAPI_WEAK void efl_io_buffered_stream_clear(Eo *obj);
 
 /**
  * @brief Marks the end-of-stream. Signals nothing else will be written.
@@ -352,7 +352,7 @@ EOAPI void efl_io_buffered_stream_clear(Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI void efl_io_buffered_stream_eos_mark(Eo *obj);
+EAPI EAPI_WEAK void efl_io_buffered_stream_eos_mark(Eo *obj);
 
 /**
  * @brief Forces writing all pending data to destination.
@@ -361,7 +361,7 @@ EOAPI void efl_io_buffered_stream_eos_mark(Eo *obj);
  * to zero, @c false otherwise and more calls to flush must be made.
  *
  * If the @ref efl_io_buffered_stream_inner_io_get implements
- * @ref Efl_Io_Closer and it is closed or the wrapper itself's closed, this
+ * @ref Efl_Io_Closer and it is closed or the wrapper itself is closed, this
  * function will do nothing and return @c true.
  *
  * @note this function may block the main loop execution until operations are
@@ -378,9 +378,9 @@ EOAPI void efl_io_buffered_stream_eos_mark(Eo *obj);
  *
  * @ingroup Efl_Io_Buffered_Stream
  */
-EOAPI Eina_Bool efl_io_buffered_stream_flush(Eo *obj, Eina_Bool may_block, Eina_Bool ignore_line_delimiter);
+EAPI EAPI_WEAK Eina_Bool efl_io_buffered_stream_flush(Eo *obj, Eina_Bool may_block, Eina_Bool ignore_line_delimiter);
 
-EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_WRITE_FINISHED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_WRITE_FINISHED;
 
 /** @ref efl_io_buffered_stream_eos_mark was called and all available data was
  * sent to destination
@@ -389,7 +389,7 @@ EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_WRITE_FIN
  */
 #define EFL_IO_BUFFERED_STREAM_EVENT_WRITE_FINISHED (&(_EFL_IO_BUFFERED_STREAM_EVENT_WRITE_FINISHED))
 
-EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_READ_FINISHED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_READ_FINISHED;
 
 /** Same as @ref Efl_Io_Reader "eos", for consistency.
  *
@@ -397,7 +397,7 @@ EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_READ_FINI
  */
 #define EFL_IO_BUFFERED_STREAM_EVENT_READ_FINISHED (&(_EFL_IO_BUFFERED_STREAM_EVENT_READ_FINISHED))
 
-EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_FINISHED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_FINISHED;
 
 /** Both read and write are finished.
  *
@@ -405,7 +405,7 @@ EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_FINISHED;
  */
 #define EFL_IO_BUFFERED_STREAM_EVENT_FINISHED (&(_EFL_IO_BUFFERED_STREAM_EVENT_FINISHED))
 
-EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_ERROR;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_ERROR;
 
 /** An error has occurred and I/O has stopped
  * @return Eina_Error
@@ -414,7 +414,7 @@ EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_ERROR;
  */
 #define EFL_IO_BUFFERED_STREAM_EVENT_ERROR (&(_EFL_IO_BUFFERED_STREAM_EVENT_ERROR))
 
-EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_PROGRESS;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_PROGRESS;
 
 /** Property @ref efl_io_buffered_stream_progress_get changed
  *
@@ -422,7 +422,7 @@ EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_PROGRESS;
  */
 #define EFL_IO_BUFFERED_STREAM_EVENT_PROGRESS (&(_EFL_IO_BUFFERED_STREAM_EVENT_PROGRESS))
 
-EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_SLICE_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_SLICE_CHANGED;
 
 /** The read-slice returned by @ref efl_io_buffered_stream_slice_get may have
  * changed.
@@ -431,7 +431,7 @@ EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_SLICE_CHA
  */
 #define EFL_IO_BUFFERED_STREAM_EVENT_SLICE_CHANGED (&(_EFL_IO_BUFFERED_STREAM_EVENT_SLICE_CHANGED))
 
-EWAPI extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_LINE;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_IO_BUFFERED_STREAM_EVENT_LINE;
 
 /** If @ref efl_io_buffered_stream_line_delimiter_get is set, will be emitted
  * with current line. The memory is only valid during event callback dispatched
